==> jc-tke-service-1.1.329-sources.jar: com/xforceplus/jctke/controller/FlowinstancelogLrr94edwdqrcw2ajregmnmController.java <==
package com.xforceplus.jctke.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jctke.entity.FlowinstancelogLrr94edwdqrcw2ajregmnm;
import com.xforceplus.jctke.service.IFlowinstancelogLrr94edwdqrcw2ajregmnmService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-11-05
 */
@RestController
public class FlowinstancelogLrr94edwdqrcw2ajregmnmController {

  @Autowired
  private IFlowinstancelogLrr94edwdqrcw2ajregmnmService flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return
   */
  @GetMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms" )
  public XfR getFlowinstancelogLrr94edwdqrcw2ajregmnms(XfPage page, FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm) {
    return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.page(page, Wrappers.query(flowinstancelogLrr94edwdqrcw2ajregmnm)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PostMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms")
  public XfR save(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.save(flowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PutMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR putUpdate(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm,@PathVariable Long id) {
      flowinstancelogLrr94edwdqrcw2ajregmnm.setId(id);
      return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.updateById(flowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PatchMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR patchUpdate(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm,@PathVariable Long id) {
      FlowinstancelogLrr94edwdqrcw2ajregmnm upflowinstancelogLrr94edwdqrcw2ajregmnm = flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.getById(id);
      if(upflowinstancelogLrr94edwdqrcw2ajregmnm != null){
        upflowinstancelogLrr94edwdqrcw2ajregmnm = ObjectCopyUtils.copyProperties(flowinstancelogLrr94edwdqrcw2ajregmnm,upflowinstancelogLrr94edwdqrcw2ajregmnm,true);
      }
      return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.updateById(upflowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.removeById(id));
  }

  @PostMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "flowinstancelog_lrr94edwdqrcw2ajregmnm");
     params.put("request", condition);

     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.querys(params));
  }

}

==> jc-tke-service-1.1.385-sources.jar: com/xforceplus/jctke/controller/FlowinstancelogLrr94edwdqrcw2ajregmnmController.java <==
package com.xforceplus.jctke.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.jctke.entity.FlowinstancelogLrr94edwdqrcw2ajregmnm;
import com.xforceplus.jctke.service.IFlowinstancelogLrr94edwdqrcw2ajregmnmService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-12-01
 */
@RestController
public class FlowinstancelogLrr94edwdqrcw2ajregmnmController {

  @Autowired
  private IFlowinstancelogLrr94edwdqrcw2ajregmnmService flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return
   */
  @GetMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms" )
  public XfR getFlowinstancelogLrr94edwdqrcw2ajregmnms(XfPage page, FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm) {
    return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.page(page, Wrappers.query(flowinstancelogLrr94edwdqrcw2ajregmnm)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PostMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms")
  public XfR save(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.save(flowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PutMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR putUpdate(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm,@PathVariable Long id) {
      flowinstancelogLrr94edwdqrcw2ajregmnm.setId(id);
      return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.updateById(flowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return XfR
   */
  @PatchMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR patchUpdate(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm,@PathVariable Long id) {
      FlowinstancelogLrr94edwdqrcw2ajregmnm upflowinstancelogLrr94edwdqrcw2ajregmnm = flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.getById(id);
      if(upflowinstancelogLrr94edwdqrcw2ajregmnm != null){
        upflowinstancelogLrr94edwdqrcw2ajregmnm = ObjectCopyUtils.copyProperties(flowinstancelogLrr94edwdqrcw2ajregmnm,upflowinstancelogLrr94edwdqrcw2ajregmnm,true);
      }
      return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.updateById(upflowinstancelogLrr94edwdqrcw2ajregmnm));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.removeById(id));
  }

  @PostMapping("/flowinstanceloglrr94edwdqrcw2ajregmnms/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "flowinstancelog_lrr94edwdqrcw2ajregmnm");
     params.put("request", condition);

     return XfR.ok(flowinstancelogLrr94edwdqrcw2ajregmnmServiceImpl.querys(params));
  }

}
